@@ -1,6 +1,6 @@
 #
 # This file is part of Language::Befunge.
-# Copyright (c) 2001-2007 Jerome Quelin, all rights reserved.
+# Copyright (c) 2001-2008 Jerome Quelin, all rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
@@ -10,39 +10,17 @@
 package Language::Befunge::IP;
 require 5.006;
 
-=head1 NAME
-
-Language::Befunge::IP - an Instruction Pointer for a Befunge-97 program.
-
-
-=head1 DESCRIPTION
-
-This is the class implementing the Instruction Pointers. An
-Instruction Pointer (aka IP) has a stack, and a stack of stacks that
-can be manipulated via the methods of the class.
-
-We need a class, since this is a concurrent Befunge, so we can have
-more than one IP travelling on the Lahey space.
-
-=cut
 use strict;
 use warnings;
 use integer;
 
-# Modules we rely upon.
+use Carp;
 use Language::Befunge::Vector;
-use Carp;     # This module can't explode :o)
 use Storable qw(dclone);
 
 
-=head1 CONSTRUCTOR
+# -- CONSTRUCTORS
 
-=head2 new( [dimensions] )
-
-Create a new Instruction Pointer, which operates in a universe of the given
-number of dimensions.  If dimensions is not specified, it defaults to 2.
-
-=cut
 sub new {
     my ($class, $dims) = @_;
     $dims = 2 unless defined $dims;
@@ -67,12 +45,6 @@ sub new {
     return $self;
 }
 
-=head2 clone(  )
-
-Clone the current Instruction Pointer with all its stacks, position,
-delta, etc. Change its unique ID.
-
-=cut
 sub clone {
     my $self = shift;
     my $clone = dclone( $self );
@@ -81,68 +53,8 @@ sub clone {
 }
 
 
-=head1 ACCESSORS
+# -- ACCESSORS
 
-=head2 Attributes
-
-The following is a list of attributes of a Language::Befunge::IP
-object. For each of them, a method C<get_foobar> and C<set_foobar>
-exists.
-
-=over 4
-
-=item get_id() / set_id()
-
-the unique ID of the IP (an integer)
-
-=item get_dims()
-
-the number of dimensions this IP operates in (an integer).  This is
-read-only.
-
-=item get_position() / set_position()
-
-the current coordinates of the IP (a vector)
-
-=item get_delta() / set_delta()
-
-the offset of the IP (a vector)
-
-=item get_storage() / set_storage()
-
-the coordinates of the storage offset of the IP (a vector)
-
-=item get_data() / set_data()
-
-the library private storage space (a hash reference)
-
-=item get_input() / set_input()
-
-the input cache (a string)
-
-=item get_string_mode() / set_string_mode()
-
-the string_mode of the IP (a boolean)
-
-=item get_end() / set_end()
-
-wether the IP should be terminated (a boolean)
-
-=item get_libs() / set_libs()
-
-the current stack of loaded libraries (an array reference)
-
-=item get_ss() / set_ss()
-
-the stack of stack of the IP (an array reference)
-
-=item get_toss() / set_toss()
-
-the current stack (er, TOSS) of the IP (an array reference)
-
-=back
-
-=cut
 BEGIN {
     my @attrs = qw[ position data delta end id input libs
                     ss storage string_mode toss ];
@@ -155,13 +67,6 @@ BEGIN {
 
 sub get_dims { return $_[0]->{dims} };
 
-=pod
-
-=head2 soss(  )
-
-Get or set the SOSS.
-
-=cut
 sub soss {
     my $self = shift;
     # Remember, the Stack Stack is up->bottom.
@@ -170,43 +75,16 @@ sub soss {
 }
 
 
-=head1 PUBLIC METHODS
-
-=head2 Internal stack
-
-In this section, I speak about the stack. In fact, this is the TOSS - that
-is, the Top Of the Stack Stack.
-
-In Befunge-98, standard stack operations occur transparently on the
-TOSS (as if there were only one stack, as in Befunge-93).
-
-=over 4
-
-=item scount(  )
-
-Return the number of elements in the stack.
-
-=cut
 sub scount {
     my $self = shift;
     return scalar @{ $self->get_toss };
 }
 
-=item spush( value )
-
-Push a value on top of the stack.
-
-=cut
 sub spush {
     my $self = shift;
     push @{ $self->get_toss }, @_;
 }
 
-=item spush_vec( vector )
-
-Push a vector on top of the stack. The x coordinate is pushed first.
-
-=cut
 sub spush_vec {
 	my ($self) = shift;
 	foreach my $v (@_) {
@@ -214,16 +92,6 @@ sub spush_vec {
 	}
 }
 
-=item spush_args ( arg, ... )
-
-Push a list of argument on top of the stack (the first argument will
-be the deeper one). Convert each argument: a number is pushed as is,
-whereas a string is pushed as a 0gnirts.
-
-B</!\> Do B<not> push references or weird arguments: this method
-supports only numbers (positive and negative) and strings.
-
-=cut
 sub spush_args {
     my $self = shift;
     foreach my $arg ( @_ ) {
@@ -235,12 +103,6 @@ sub spush_args {
     }
 }
 
-=item spop(  )
-
-Pop a value from the stack. If the stack is empty, no error occurs and
-the method acts as if it popped a 0.
-
-=cut
 sub spop {
     my $self = shift;
     my $val = pop @{ $self->get_toss };
@@ -248,33 +110,17 @@ sub spop {
     return $val;
 }
 
-=item spop_mult( <count> )
-
-Pop multiple values from the stack. If the stack becomes empty, the
-remainder of the returned values will be 0.
-
-=cut
 sub spop_mult {
     my ($self, $count) = @_;
     my @rv = reverse map { $self->spop() } (1..$count);
     return @rv;
 }
 
-=item spop_vec(  )
-
-Pop a vector from the stack. Returns a Vector object.
-
-=cut
 sub spop_vec {
     my $self = shift;
-    return Language::Befunge::Vector->new($self->get_dims, $self->spop_mult($self->get_dims));
+    return Language::Befunge::Vector->new($self->spop_mult($self->get_dims));
 }
 
-=item spop_gnirts(  )
-
-Pop a 0gnirts string from the stack.
-
-=cut
 sub spop_gnirts {
     my $self = shift;
     my ($val, $str);
@@ -287,24 +133,11 @@ sub spop_gnirts {
     return $str;
 }
 
-=item sclear(  )
-
-Clear the stack.
-
-=cut
 sub sclear {
     my $self = shift;
     $self->set_toss( [] );
 }
 
-=item svalue( offset )
-
-Return the C<offset>th value of the TOSS, counting from top of the
-TOSS. The offset is interpreted as a negative value, that is, a call
-with an offset of C<2> or C<-2> would return the second value on top
-of the TOSS.
-
-=cut
 sub svalue {
     my ($self, $idx) = @_;
 
@@ -313,37 +146,11 @@ sub svalue {
     return $self->get_toss->[$idx];
 }
 
-=back
-
-
-=head2 Stack stack
-
-This section discusses about the stack stack. We can speak here about
-TOSS (Top Of Stack Stack) and SOSS (second on stack stack).
-
-=over 4
-
-=item ss_count(  )
-
-Return the number of stacks in the stack stack. This of course does
-not include the TOSS itself.
-
-=cut
 sub ss_count {
     my $self = shift;
     return scalar( @{ $self->get_ss } );
 }
 
-=item ss_create( count )
-
-Push the TOSS on the stack stack and create a new stack, aimed to be
-the new TOSS. Once created, transfer C<count> elements from the SOSS
-(the former TOSS) to the TOSS. Transfer here means move - and B<not>
-copy -, furthermore, order is preserved.
-
-If count is negative, then C<count> zeroes are pushed on the new TOSS.
-
-=cut
 sub ss_create {
     my ( $self, $n ) = @_;
 
@@ -374,12 +181,6 @@ sub ss_create {
     $self->set_toss( \@new_toss );
 }
 
-=item ss_remove( count )
-
-Move C<count> elements from TOSS to SOSS, discard TOSS and make the
-SOSS become the new TOSS. Order of elems is preserved.
-
-=cut
 sub ss_remove {
     my ( $self, $n ) = @_;
 
@@ -411,14 +212,6 @@ sub ss_remove {
     $self->set_toss( $new_toss );
 }
 
-=item ss_transfer( count )
-
-Transfer C<count> elements from SOSS to TOSS, or from TOSS to SOSS if
-C<count> is negative; the transfer is done via pop/push.
-
-The order is not preserved, it is B<reversed>.
-
-=cut
 sub ss_transfer {
     my ($self, $n) = @_;
     $n == 0 and return;
@@ -451,12 +244,6 @@ sub ss_transfer {
     }
 }
 
-=item ss_sizes(  )
-
-Return a list with all the sizes of the stacks in the stack stack
-(including the TOSS), from the TOSS to the BOSS.
-
-=cut
 sub ss_sizes {
     my $self = shift;
 
@@ -471,44 +258,23 @@ sub ss_sizes {
 }
 
 
-=item soss_count(  )
-
-Return the number of elements in SOSS.
-
-=cut
 sub soss_count {
     my $self = shift;
     return scalar( @{ $self->soss } );
 }
 
-=item soss_push( value )
-
-Push a value on top of the SOSS.
-
-=cut
 sub soss_push {
     my $self = shift;
     push @{ $self->soss }, @_;
 }
 
 
-=item soss_pop_mult( <count> )
-
-Pop multiple values from the SOSS. If the stack becomes empty, the
-remainder of the returned values will be 0.
-
-=cut
 sub soss_pop_mult {
     my ($self, $count) = @_;
     my @rv = reverse map { $self->soss_pop() } (1..$count);
     return @rv;
 }
 
-=item soss_push_vec( vector )
-
-Push a vector on top of the SOSS.
-
-=cut
 sub soss_push_vec {
     my $self = shift;
 	foreach my $v (@_) {
@@ -516,12 +282,6 @@ sub soss_push_vec {
 	}
 }
 
-=item soss_pop(  )
-
-Pop a value from the SOSS. If the stack is empty, no error occurs and
-the method acts as if it popped a 0.
-
-=cut
 sub soss_pop {
     my $self = shift;
     my $val = pop @{ $self->soss };
@@ -529,22 +289,11 @@ sub soss_pop {
     return $val;
 }
 
-=item soss_pop_vec(  )
-
-Pop a vector from the SOSS. If the stack is empty, no error occurs
-and the method acts as if it popped a 0.  returns a Vector.
-
-=cut
 sub soss_pop_vec {
     my $self = shift;
-    return Language::Befunge::Vector->new($self->get_dims, $self->soss_pop_mult($self->get_dims));
+    return Language::Befunge::Vector->new($self->soss_pop_mult($self->get_dims));
 }
 
-=item soss_clear(  )
-
-Clear the SOSS.
-
-=cut
 sub soss_clear {
     my $self = shift;
     $self->soss( [] );
@@ -552,6 +301,394 @@ sub soss_clear {
 
 
 
+sub dir_go_east {
+    my $self = shift;
+    $self->get_delta->clear;
+    $self->get_delta->set_component(0, 1);
+}
+
+sub dir_go_west {
+    my $self = shift;
+    $self->get_delta->clear;
+    $self->get_delta->set_component(0, -1);
+}
+
+sub dir_go_north {
+    my $self = shift;
+    $self->get_delta->clear;
+    $self->get_delta->set_component(1, -1);
+}
+
+sub dir_go_south {
+    my $self = shift;
+    $self->get_delta->clear;
+    $self->get_delta->set_component(1, 1);
+}
+
+sub dir_go_high {
+    my $self = shift;
+    $self->get_delta->clear;
+    $self->get_delta->set_component(2, 1);
+}
+
+sub dir_go_low {
+    my $self = shift;
+    $self->get_delta->clear;
+    $self->get_delta->set_component(2, -1);
+}
+
+sub dir_go_away {
+    my $self = shift;
+    my $nd = $self->get_dims;
+    my $dim = (0..$nd-1)[int(rand $nd)];
+    $self->get_delta->clear;
+    my $value = (-1, 1)[int(rand 2)];
+    $self->get_delta->set_component($dim, $value);
+}
+
+sub dir_turn_left {
+    my $self = shift;
+    my $old_dx = $self->get_delta->get_component(0);
+    my $old_dy = $self->get_delta->get_component(1);
+    $self->get_delta->set_component(0, 0 + $old_dy);
+    $self->get_delta->set_component(1, 0 + $old_dx * -1);
+}
+
+sub dir_turn_right {
+    my $self = shift;
+    my $old_dx = $self->get_delta->get_component(0);
+    my $old_dy = $self->get_delta->get_component(1);
+    $self->get_delta->set_component(0, 0 + $old_dy * -1);
+    $self->get_delta->set_component(1, 0 + $old_dx);
+}
+
+sub dir_reverse {
+    my $self = shift;
+    $self->set_delta(-$self->get_delta);
+}
+
+sub load {
+    my ($self, $lib) = @_;
+    unshift @{ $self->get_libs }, $lib;
+}
+
+sub unload {
+    my ($self, $lib) = @_;
+
+    my $offset = -1;
+    foreach my $i ( 0..$#{$self->get_libs} ) {
+        $offset = $i, last if ref($self->get_libs->[$i]) eq $lib;
+    }
+    $offset == -1 and return undef;
+    splice @{ $self->get_libs }, $offset, 1;
+    return $lib;
+}
+
+sub extdata {
+    my $self = shift;
+    my $lib  = shift;
+    @_ ? $self->get_data->{$lib} = shift : $self->get_data->{$lib};
+}
+
+
+# -- PRIVATE METHODS
+
+#
+# my $id = _get_new_id;
+#
+# Forge a new IP id, that will distinct it from the other IPs of the program.
+#
+my $id = 0;
+sub _get_new_id {
+    return $id++;
+}
+
+1;
+__END__
+
+=head1 NAME
+
+Language::Befunge::IP - an Instruction Pointer for a Befunge-98 program.
+
+
+
+=head1 DESCRIPTION
+
+This is the class implementing the Instruction Pointers. An
+Instruction Pointer (aka IP) has a stack, and a stack of stacks that
+can be manipulated via the methods of the class.
+
+We need a class, since this is a concurrent Befunge, so we can have
+more than one IP travelling on the Lahey space.
+
+
+
+=head1 CONSTRUCTORS
+
+=head2 my $ip = LB::IP->new( [$dimensions] )
+
+Create a new Instruction Pointer, which operates in a universe of the given
+C<$dimensions>. If C<$dimensions> is not specified, it defaults to 2
+(befunge world).
+
+
+=head2 my $clone = $ip->clone()
+
+Clone the current Instruction Pointer with all its stacks, position,
+delta, etc. Change its unique ID.
+
+
+
+=head1 ACCESSORS
+
+=head2 Attributes
+
+The following is a list of attributes of a Language::Befunge::IP
+object. For each of them, a method C<get_foobar> and C<set_foobar>
+exists.
+
+
+=over 4
+
+=item $ip->get_id() / $ip->set_id($id)
+
+The unique ID of the IP (an integer). Don't set the ID yourself.
+
+
+=item $ip->get_dims()
+
+The number of dimensions this IP operates in (an integer). This is
+read-only.
+
+
+=item $ip->get_position() / $ip->set_position($vec)
+
+The current coordinates of the IP (a C<Language::Befunge::Vector>
+object).
+
+
+=item $ip->get_delta() / $ip->set_delta($vec)
+
+The velocity of the IP (a C<Language::Befunge::Vector> object).
+
+
+=item $ip->get_storage() / $ip->set_storage($vec)
+
+The coordinates of the storage offset of the IP (a
+C<Language::Befunge::Vector> object).
+
+
+=item $ip->get_data() / $ip->set_data({})
+
+The library private storage space (a hash reference). Don't set this
+yourself.
+FIXME: not supposed to be accessible
+
+
+=item $ip->get_input() / $ip->set_input($str)
+
+The input cache (a string).
+
+
+=item $ip->get_string_mode() / set_string_mode($bool)
+
+The string_mode of the IP (a boolean).
+
+
+=item $ip->get_end() / $ip->set_end($bool)
+
+Whether the IP should be terminated (a boolean).
+
+
+=item $ip->get_libs() / $ip->set_libs($aref)
+
+The current stack of loaded libraries (an array reference). Don't set
+this yourself.
+FIXME: not supposed to be accessible
+
+
+=item $ip->get_ss() / $ip->set_ss($aref)
+
+The stack of stack of the IP (an array reference). Don't set this
+yourself.
+FIXME: not supposed to be accessible
+
+
+=item $ip->get_toss() / $ip->set_toss($aref)
+
+The current stack (er, TOSS) of the IP (an array reference). Don't set
+this yourself.
+FIXME: not supposed to be accessible
+
+
+=back
+
+
+=head2 $ip->soss([$])
+
+Get or set the SOSS.
+
+
+
+=head1 PUBLIC METHODS
+
+=head2 Internal stack
+
+In this section, I speak about the stack. In fact, this is the TOSS - that
+is, the Top Of the Stack Stack.
+
+In Befunge-98, standard stack operations occur transparently on the
+TOSS (as if there were only one stack, as in Befunge-93).
+
+
+=over 4
+
+=item scount(  )
+
+Return the number of elements in the stack.
+
+
+=item spush( value )
+
+Push a value on top of the stack.
+
+
+=item spush_vec( vector )
+
+Push a vector on top of the stack. The x coordinate is pushed first.
+
+
+=item spush_args ( arg, ... )
+
+Push a list of argument on top of the stack (the first argument will
+be the deeper one). Convert each argument: a number is pushed as is,
+whereas a string is pushed as a 0gnirts.
+
+B</!\> Do B<not> push references or weird arguments: this method
+supports only numbers (positive and negative) and strings.
+
+
+=item spop(  )
+
+Pop a value from the stack. If the stack is empty, no error occurs and
+the method acts as if it popped a 0.
+
+
+=item spop_mult( <count> )
+
+Pop multiple values from the stack. If the stack becomes empty, the
+remainder of the returned values will be 0.
+
+
+=item spop_vec(  )
+
+Pop a vector from the stack. Returns a Vector object.
+
+
+=item spop_gnirts(  )
+
+Pop a 0gnirts string from the stack.
+
+
+=item sclear(  )
+
+Clear the stack.
+
+
+=item svalue( offset )
+
+Return the C<offset>th value of the TOSS, counting from top of the
+TOSS. The offset is interpreted as a negative value, that is, a call
+with an offset of C<2> or C<-2> would return the second value on top
+of the TOSS.
+
+
+=back
+
+
+=head2 Stack stack
+
+This section discusses about the stack stack. We can speak here about
+TOSS (Top Of Stack Stack) and SOSS (second on stack stack).
+
+=over 4
+
+=item ss_count(  )
+
+Return the number of stacks in the stack stack. This of course does
+not include the TOSS itself.
+
+
+
+=item ss_create( count )
+
+Push the TOSS on the stack stack and create a new stack, aimed to be
+the new TOSS. Once created, transfer C<count> elements from the SOSS
+(the former TOSS) to the TOSS. Transfer here means move - and B<not>
+copy -, furthermore, order is preserved.
+
+If count is negative, then C<count> zeroes are pushed on the new TOSS.
+
+
+=item ss_remove( count )
+
+Move C<count> elements from TOSS to SOSS, discard TOSS and make the
+SOSS become the new TOSS. Order of elems is preserved.
+
+
+=item ss_transfer( count )
+
+Transfer C<count> elements from SOSS to TOSS, or from TOSS to SOSS if
+C<count> is negative; the transfer is done via pop/push.
+
+The order is not preserved, it is B<reversed>.
+
+
+=item ss_sizes(  )
+
+Return a list with all the sizes of the stacks in the stack stack
+(including the TOSS), from the TOSS to the BOSS.
+
+
+=item soss_count(  )
+
+Return the number of elements in SOSS.
+
+
+=item soss_push( value )
+
+Push a value on top of the SOSS.
+
+
+=item soss_pop_mult( <count> )
+
+Pop multiple values from the SOSS. If the stack becomes empty, the
+remainder of the returned values will be 0.
+
+
+=item soss_push_vec( vector )
+
+Push a vector on top of the SOSS.
+
+
+
+=item soss_pop(  )
+
+Pop a value from the SOSS. If the stack is empty, no error occurs and
+the method acts as if it popped a 0.
+
+
+=item soss_pop_vec(  )
+
+Pop a vector from the SOSS. If the stack is empty, no error occurs
+and the method acts as if it popped a 0.  returns a Vector.
+
+
+=item soss_clear(  )
+
+Clear the SOSS.
+
+
 =back
 
 
@@ -563,23 +700,11 @@ sub soss_clear {
 
 Implements the C<E<gt>> instruction. Force the IP to travel east.
 
-=cut
-sub dir_go_east {
-    my $self = shift;
-    $self->get_delta->zero();
-    $self->get_delta->set_component(0, 1);
-}
 
 =item dir_go_west(  )
 
 Implements the C<E<lt>> instruction. Force the IP to travel west.
 
-=cut
-sub dir_go_west {
-    my $self = shift;
-    $self->get_delta->zero();
-    $self->get_delta->set_component(0, -1);
-}
 
 =item dir_go_north(  )
 
@@ -587,12 +712,6 @@ Implements the C<^> instruction. Force the IP to travel north.
 
 Not valid for Unefunge.
 
-=cut
-sub dir_go_north {
-    my $self = shift;
-    $self->get_delta->zero();
-    $self->get_delta->set_component(1, -1);
-}
 
 =item dir_go_south(  )
 
@@ -600,12 +719,6 @@ Implements the C<v> instruction. Force the IP to travel south.
 
 Not valid for Unefunge.
 
-=cut
-sub dir_go_south {
-    my $self = shift;
-    $self->get_delta->zero();
-    $self->get_delta->set_component(1, 1);
-}
 
 =item dir_go_high(  )
 
@@ -613,12 +726,6 @@ Implements the C<h> instruction. Force the IP to travel up.
 
 Not valid for Unefunge or Befunge.
 
-=cut
-sub dir_go_high {
-    my $self = shift;
-    $self->get_delta->zero();
-    $self->get_delta->set_component(2, 1);
-}
 
 =item dir_go_low(  )
 
@@ -626,12 +733,6 @@ Implements the C<l> instruction. Force the IP to travel down.
 
 Not valid for Unefunge or Befunge.
 
-=cut
-sub dir_go_low {
-    my $self = shift;
-    $self->get_delta->zero();
-    $self->get_delta->set_component(2, -1);
-}
 
 =item dir_go_away(  )
 
@@ -639,15 +740,6 @@ Implements the C<?> instruction. Cause the IP to travel in a random
 cardinal direction (in Befunge's case, one of: north, south, east or
 west).
 
-=cut
-sub dir_go_away {
-    my $self = shift;
-    my $nd = $self->get_dims;
-    my $dim = (0..$nd-1)[int(rand $nd)];
-    $self->get_delta->zero();
-    my $value = (-1, 1)[int(rand 2)];
-    $self->get_delta->set_component($dim, $value);
-}
 
 =item dir_turn_left(  )
 
@@ -657,14 +749,6 @@ delta of the IP which encounters this instruction.
 Not valid for Unefunge.  For Trefunge and greater, only affects the
 X and Y axes.
 
-=cut
-sub dir_turn_left {
-    my $self = shift;
-    my $old_dx = $self->get_delta->get_component(0);
-    my $old_dy = $self->get_delta->get_component(1);
-    $self->get_delta->set_component(0, 0 + $old_dy);
-    $self->get_delta->set_component(1, 0 + $old_dx * -1);
-}
 
 =item dir_turn_right(  )
 
@@ -674,25 +758,14 @@ delta of the IP which encounters this instruction.
 Not valid for Unefunge.  For Trefunge and higher dimensions, only
 affects the X and Y axes.
 
-=cut
-sub dir_turn_right {
-    my $self = shift;
-    my $old_dx = $self->get_delta->get_component(0);
-    my $old_dy = $self->get_delta->get_component(1);
-    $self->get_delta->set_component(0, 0 + $old_dy * -1);
-    $self->get_delta->set_component(1, 0 + $old_dx);
-}
+
 
 =item dir_reverse(  )
 
 Implements the C<r> instruction. Reverse the direction of the IP, that
 is, multiply the IP's delta by -1.
 
-=cut
-sub dir_reverse {
-    my $self = shift;
-    $self->set_delta($self->get_delta->vector_invert());
-}
+
 
 =back
 
@@ -705,11 +778,7 @@ sub dir_reverse {
 Load the given library semantics. The parameter is an extension object
 (a library instance).
 
-=cut
-sub load {
-    my ($self, $lib) = @_;
-    unshift @{ $self->get_libs }, $lib;
-}
+
 
 =item unload( lib )
 
@@ -723,18 +792,6 @@ unload the most recent library. Ie, if an IP has loaded the libraries
 then the IP will follow the semantics of C<BAZ>, then C<BAR>, then
 <FOO> (!).
 
-=cut
-sub unload {
-    my ($self, $lib) = @_;
-
-    my $offset = -1;
-    foreach my $i ( 0..$#{$self->get_libs} ) {
-        $offset = $i, last if ref($self->get_libs->[$i]) eq $lib;
-    }
-    $offset == -1 and return undef;
-    splice @{ $self->get_libs }, $offset, 1;
-    return $lib;
-}
 
 =item extdata( library, [value] )
 
@@ -744,29 +801,9 @@ reserved for libraries that need to store internal values.
 Since in Perl references are plain scalars, one can store a reference
 to an array or even a hash.
 
-=cut
-sub extdata {
-    my $self = shift;
-    my $lib  = shift;
-    @_ ? $self->get_data->{$lib} = shift : $self->get_data->{$lib};
-}
-
 =back
 
-=head1 PRIVATE METHODS
 
-=head2 _get_new_id(  )
-
-Forge a new IP id, that will distinct it from the other IPs of the program.
-
-=cut
-my $id = 0;
-sub _get_new_id {
-    return $id++;
-}
-
-1;
-__END__
 
 
 =head1 SEE ALSO
@@ -779,9 +816,10 @@ L<Language::Befunge>.
 Jerome Quelin, E<lt>jquelin@cpan.orgE<gt>
 
 
+
 =head1 COPYRIGHT & LICENSE
 
-Copyright (c) 2001-2007 Jerome Quelin, all rights reserved.
+Copyright (c) 2001-2008 Jerome Quelin, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
